package yocaml_markdown

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Pipeline.With_metadataSource

Sourceval make : ?strict:bool -> ?heading_auto_ids:bool -> ?highlight:(Cmarkit.Doc.t -> Cmarkit.Doc.t) -> ?safe:bool -> unit -> ('a * string, 'a * string) Yocaml.Task.t

Convert a Markdown string to an HTML String taking metadata in account.

Sourceval make_with_table_of_contents : ?strict:bool -> ?heading_auto_ids:bool -> ?highlight:(Cmarkit.Doc.t -> Cmarkit.Doc.t) -> ?traverse_table:((string * string) Yocaml.Markup.Toc.t -> string option) -> ?safe:bool -> unit -> ('a * string, ('a * string option) * string) Yocaml.Task.t

Same as make but with table of contents handling.

Sourceval to_doc : ?strict:bool -> ?heading_auto_ids:bool -> ?highlight:(Cmarkit.Doc.t -> Cmarkit.Doc.t) -> unit -> ('a * string, 'a * Cmarkit.Doc.t) Yocaml.Task.t

A Task for converting a string into a Cmarkit document.

Sourceval table_of_contents : ?traverse_table:((string * string) Yocaml.Markup.Toc.t -> string option) -> unit -> ('a * Cmarkit.Doc.t, ('a * string option) * Cmarkit.Doc.t) Yocaml.Task.t
Sourceval with_table_of_contents : ?strict:bool -> ?heading_auto_ids:bool -> ?highlight:(Cmarkit.Doc.t -> Cmarkit.Doc.t) -> ?traverse_table:((string * string) Yocaml.Markup.Toc.t -> string option) -> unit -> ('a * string, ('a * string option) * Cmarkit.Doc.t) Yocaml.Task.t

Convert a document and collapse the table of content into the metadata field.

Sourceval to_html : ?safe:bool -> unit -> ('a * Cmarkit.Doc.t, 'a * string) Yocaml.Task.t